@@ -208,17 +208,17 @@ class DynamoDBStreamsToLambda(
 
         jsii.create(self.__class__, self, [scope, id, props])
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="dynamoTableInterface")
     def dynamo_table_interface(self) -> aws_cdk.aws_dynamodb.ITable:
         return typing.cast(aws_cdk.aws_dynamodb.ITable, jsii.get(self, "dynamoTableInterface"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="lambdaFunction")
     def lambda_function(self) -> aws_cdk.aws_lambda.Function:
         return typing.cast(aws_cdk.aws_lambda.Function, jsii.get(self, "lambdaFunction"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="dynamoTable")
     def dynamo_table(self) -> typing.Optional[aws_cdk.aws_dynamodb.Table]:
         return typing.cast(typing.Optional[aws_cdk.aws_dynamodb.Table], jsii.get(self, "dynamoTable"))
@@ -261,11 +261,11 @@ class DynamoDBStreamsToLambdaProps:
         :summary: The properties for the DynamoDBStreamsToLambda Construct
         '''
         if isinstance(dynamo_table_props, dict):
-            dynamo_table_props = aws_cdk.aws_dynamodb.TableProps(**dynamo_table_props)
+            dynamo_table_props = TableProps(**dynamo_table_props)
         if isinstance(lambda_function_props, dict):
-            lambda_function_props = aws_cdk.aws_lambda.FunctionProps(**lambda_function_props)
+            lambda_function_props = FunctionProps(**lambda_function_props)
         if isinstance(sqs_dlq_queue_props, dict):
-            sqs_dlq_queue_props = aws_cdk.aws_sqs.QueueProps(**sqs_dlq_queue_props)
+            sqs_dlq_queue_props = QueueProps(**sqs_dlq_queue_props)
         if __debug__:
             type_hints = typing.get_type_hints(DynamoDBStreamsToLambdaProps.__init__)
             check_type(argname="argument deploy_sqs_dlq_queue", value=deploy_sqs_dlq_queue, expected_type=type_hints["deploy_sqs_dlq_queue"])
